@@ -2,7 +2,7 @@
  * Some parts of this file may be from zeemoted, which is also under GPL.
  *
  * All original portions are
- * Copyright (C) 2009 <davidfalkayn@gmail.com>.
+ * Copyright (C) 2010 <davidfalkayn@gmail.com>.
  *
  * Accelemymote is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -31,6 +31,11 @@ inline float deg_to_rad(int degrees)
   return PI*degrees/180.0;
 }
 
+inline float rad_to_deg(float radians)
+{
+  return 180*radians/PI;
+}
+
 static int handler(void* setting, const char* section, const char* name, const char* value) // Ini file parse handler
 { // Requires global debug variable as-is
     configuration* config = (configuration*)setting;
@@ -54,6 +59,8 @@ static int handler(void* setting, const char* section, const char* name, const c
         config->threshold_roll = deg_to_rad(atoi(value));
     } else if (MATCH("control", "threshold_pitch")) {
         config->threshold_pitch = deg_to_rad(atoi(value));
+    } else if (MATCH("control", "deadzone")) {
+        config->deadzone = atof(value);
     } else if (MATCH("control", "profile")) {
         config->profile = strdup(value);
     } else if (MATCH("control", "turtle")) {
@@ -194,11 +201,11 @@ int main(int argc, char **argv)
     frames++;
 
     // Monitor the state of the config file and trigger file infrequently
-    if (!(frames % 10) && status_poll < time(0)-5){
+    if (!(frames % 10) && status_poll < time(0)-2){
       status_poll = time(0);
       if (trigger_filename[0] && access(trigger_filename, F_OK)) break; // if trigger file is gone, quit...
       stat(config_file, &cfg_stat);
-      if (cfg_stat.st_mtime > config.freshness) { // or if configuration has been modified...
+      if (cfg_stat.st_mtime > config.freshness) { // If configuration has been modified...
         if (ini_parse(config_file, handler, &config) < 0){
           printf("Error: can't refresh configuration from %s!\n", config_file);
           return 0;
@@ -236,6 +243,19 @@ int main(int argc, char **argv)
     // TODO: Keep state and/or watch total acceleration to subtract out "gestures". Also, the math could probably use some work.
     acc = sqrtf(((long)ax)*ax + ((long)ay)*ay + ((long)az)*az);  //Use long to avoid overflow when squaring ~1000 to get vector length!
 
+    if (config.offset_pitch > 15 ) { // deg_to_rad( 900 ) = 15.7--A calibration has been requested. Wait for it...
+      if (time(0)-4 > config.freshness){
+        current.pitch = asinf(ay / acc);
+        char temp[300];
+        sprintf(temp, "sed -i 's/\\(offset_pitch *= *\\)[0-9]*\\(.*\\)/\\1%0.0f\\2/' /home/user/.accelemymote/main.cfg",rad_to_deg(-current.pitch));
+	system(temp);
+        sprintf(temp, "run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"Accelemymote: neutral calibrated to %0.0f.\"",rad_to_deg(-current.pitch));
+        system(temp);
+	printf("Accelemymote: neutral calibrated to %0.0f degrees.\n", rad_to_deg(-current.pitch));
+      }
+      continue; // skip events while waiting for calibration 
+    }
+
     current.pitch = asinf(ay / acc)+config.offset_pitch;
     current.roll = -asinf(ax / acc);
     if (debug && !(frames%24)) 
@@ -258,6 +278,23 @@ int main(int argc, char **argv)
       }
     }
 
+    // Subtract deadzone range
+    if (current.roll * current.roll < (config.max_roll * config.deadzone) * (config.max_roll * config.deadzone)){
+      current.roll = 0.0;
+    } else if (current.roll > 0) {
+      current.roll = current.roll - config.max_roll * config.deadzone * 1.0/(1.0-config.deadzone);
+    } else {
+      current.roll = current.roll + config.max_roll * config.deadzone * 1.0/(1.0-config.deadzone);
+    }
+
+    if (current.pitch * current.pitch < (config.max_pitch * config.deadzone) * (config.max_pitch * config.deadzone)){
+      current.pitch = 0.0;
+    } else if (current.pitch > 0) {
+      current.pitch = current.pitch - config.max_pitch * config.deadzone * 1.0/(1.0-config.deadzone);
+    } else {
+      current.pitch = current.pitch + config.max_pitch * config.deadzone * 1.0/(1.0-config.deadzone);
+    }
+
     // Send significantly changed control states to UINPUT
     if ((current.roll-previous.roll) * (current.roll-previous.roll) > config.threshold_roll*config.threshold_roll) // abs()
     {
