@@ -6,7 +6,7 @@
 
 #include <time.h> // nanosleep()
 
-#define VERSION "0.0.7"
+#define VERSION "0.1.0"
 #define MAX_AXIS 0xFFFF		// SDL's joystick axis is stored in 16 bit int
 #define PI 3.1415
 #define ONE_SECOND 1000000000lu	// for nanosleep			
@@ -24,7 +24,7 @@ static const char *accel_filename = "/sys/class/i2c-adapter/i2c-3/3-001d/coord";
 static const char *prox_filename = "/sys/devices/platform/gpio-switch/proximity/state";
 
 /* Trigger file. When it goes, shutdown. Empty string for no kill file **This will eat about 0.5% CPU cycles until you kill it**.*/
-static const char *trigger_filename = "/home/user/.accelemymote/live-trigger";	// Yes i'm an evil evil man for hardcoding this. TODO: make parameter
+static const char *trigger_filename = "/tmp/accelemymote-live"; // Now in tmp so as not to survive a crash/reboot
 
 typedef struct
 {
@@ -40,6 +40,7 @@ typedef struct
 	float offset_pitch;	// The amount of backwards tilt to the neutral position (from flat, face up)
 	float max_roll;	// The greatest tilt that will be detected, in degrees
 	float max_pitch;	// The greatest tilt that will be detected, in degrees
+	float deadzone;	// Fraction of max angle required before joystick is considered to be off-center
 	float threshold_roll;	// The change in tilt necessary to trigger a new event, in degrees
 	float threshold_pitch;	// The change in tilt necessary to trigger a new event, in degrees
 	const char* profile;	// The type of control elements to emulate. Currently not used.
