@@ -1,8 +1,8 @@
 # If the trigger file doesn't exist, create it and start the accelemymote daemon. If it does exist, remove it (killing the daemon) and don't start.
-if [ ! -f ~/.accelemymote/live-trigger ]
+if [ ! -f /tmp/accelemymote-live ]
 then
-touch ~/.accelemymote/live-trigger
+touch /tmp/accelemymote-live
 /opt/maemo/usr/bin/accelemymote
 fi
-rm ~/.accelemymote/live-trigger
+rm /tmp/accelemymote-live
 
