@@ -109,6 +109,10 @@ int init_uinput_device()
     return -1;
   }
 
+  if(ioctl(fd, UI_SET_EVBIT, EV_KEY) < 0) perror("setting EV_KEY");
+  if(ioctl(fd, UI_SET_KEYBIT, BTN_A) < 0) perror("setting BTN_A");
+
+
   if(ioctl(fd, UI_SET_EVBIT, EV_ABS) < 0) perror("setting EV_ABS");
   if(ioctl(fd, UI_SET_ABSBIT, ABS_X) < 0) perror("setting ABS_X");
   if(ioctl(fd, UI_SET_ABSBIT, ABS_Y) < 0) perror("setting ABS_Y");
